//
//  ViewController.swift
//  Notifications
//
//  Created by Matthew Newill on 10/05/2017.
//  Copyright © 2017 Mobient. All rights reserved.
//

import UIKit
import UserNotifications

class ViewController: UIViewController, UNUserNotificationCenterDelegate {

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        UNUserNotificationCenter.current().delegate = self

    }

    @IBAction func sendNotificationIn5Seconds() {
        let centre = UNUserNotificationCenter.current()
        centre.getNotificationSettings { (settings) in
            if settings.authorizationStatus != UNAuthorizationStatus.authorized {
                print("Not Authorised")
            } else {
                print("Authorised")
                let content = UNMutableNotificationContent()
                content.title = NSString.localizedUserNotificationString(forKey: "This is the title", arguments: nil)
                content.body = NSString.localizedUserNotificationString(forKey: "The message body goes here.", arguments: nil)
                content.categoryIdentifier = "Category"
                // Deliver the notification in five seconds.
                content.sound = UNNotificationSound.default()
                let trigger = UNTimeIntervalNotificationTrigger(timeInterval: 5, repeats: false)
                
                // Schedule the notification.
                let request = UNNotificationRequest(identifier: "FiveSecond", content: content, trigger: trigger)
                let center = UNUserNotificationCenter.current()
                
                let completeAction = UNNotificationAction.init(identifier: "Complete", title: "Complete", options: UNNotificationActionOptions())
                let editAction = UNNotificationAction.init(identifier: "Edit", title: "Edit", options: UNNotificationActionOptions.foreground)
                let deleteAction = UNNotificationAction.init(identifier: "Delete", title: "Delete", options: UNNotificationActionOptions.destructive)
                let categories = UNNotificationCategory.init(identifier: "Category", actions: [completeAction, editAction, deleteAction], intentIdentifiers: [], options: [])
                
                centre.setNotificationCategories([categories])
                
                center.add(request, withCompletionHandler: nil)
            }
        }
    }
    
    func userNotificationCenter(_ center: UNUserNotificationCenter, didReceive response: UNNotificationResponse, withCompletionHandler completionHandler: @escaping () -> Void) {
        print("Test: \(response.notification.request.identifier)")
        switch response.actionIdentifier {
        case "Complete":
            print("Complete")
            completionHandler()
        case "Edit":
            print("Edit")
            completionHandler()
        case "Delete":
            print("Delete")
            completionHandler()
        default:
            completionHandler()
        }
        completionHandler()
    }
    
    func userNotificationCenter(_ center: UNUserNotificationCenter, willPresent notification: UNNotification, withCompletionHandler completionHandler: @escaping (UNNotificationPresentationOptions) -> Void) {
        print("Test Foreground: \(notification.request.identifier)")
        completionHandler([.alert, .sound])
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}
